@@ -2,8 +2,10 @@
 /**
  * @author Björn Schießle <schiessle@owncloud.com>
  * @author Joas Schilling <nickvergessen@owncloud.com>
+ * @author Morris Jobke <hey@morrisjobke.de>
+ * @author Roeland Jago Douma <rullzer@owncloud.com>
  *
- * @copyright Copyright (c) 2015, ownCloud, Inc.
+ * @copyright Copyright (c) 2016, ownCloud, Inc.
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -23,10 +25,12 @@ use OCA\Files_Sharing\Migration;
 
 $installedVersion = \OC::$server->getConfig()->getAppValue('files_sharing', 'installed_version');
 
-// Migration OC7 -> OC8
-if (version_compare($installedVersion, '0.6.0', '<')) {
-	$m = new Migration();
-	$m->addAcceptRow();
+// Migration OC8.2 -> OC9
+if (version_compare($installedVersion, '0.9.1', '<')) {
+	$m = new Migration(\OC::$server->getDatabaseConnection());
+	$m->removeReShares();
+	$m->updateInitiatorInfo();
 }
 
 \OC::$server->getJobList()->add('OCA\Files_sharing\Lib\DeleteOrphanedSharesJob');
+\OC::$server->getJobList()->add('OCA\Files_sharing\ExpireSharesJob');
