@@ -12,7 +12,6 @@ OC.L10N.register(
     "Updated \"%s\" to %s" : "„%s“ ажириран на %s",
     "Repair warning: " : "Упозорење о поправци :",
     "Repair error: " : "Грешка поправке:",
-    "Following incompatible apps have been disabled: %s" : "Следеће неусаглашене апликације су искључене: %s",
     "Following apps have been disabled: %s" : "Следеће апликације су искључене: %s",
     "File is too big" : "Фајл је превелик",
     "Invalid file provided" : "Понуђени фајл је неисправан",
@@ -23,6 +22,10 @@ OC.L10N.register(
     "No crop data provided" : "Нема података о опсецању",
     "No valid crop data provided" : "Нема података о опсецању",
     "Crop is not square" : "Опсецање није квадрат",
+    "Couldn't reset password because the token is invalid" : "Није могуће ресетовати лозинку јер je токен неважећи",
+    "Couldn't send reset email. Please make sure your username is correct." : "Не могу да пошаљем поруку за ресетовање лозинке. Проверите да ли је корисничко име исправно.",
+    "%s password reset" : "%s лозинка ресетована",
+    "Couldn't send reset email. Please contact your administrator." : "Не могу да пошаљем е-пошту за ресетовање лозинке. Контактирајте администратора.",
     "Sunday" : "недеља",
     "Monday" : "понедељак",
     "Tuesday" : "уторак",
@@ -70,8 +73,8 @@ OC.L10N.register(
     "Dec." : "дец",
     "Settings" : "Поставке",
     "Saving..." : "Уписујем...",
+    "Dismiss" : "Откажи",
     "seconds ago" : "пре пар секунди",
-    "Couldn't send reset email. Please contact your administrator." : "Не могу да пошаљем е-пошту за ресетовање лозинке. Контактирајте администратора.",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Веза за ресетовање лозинке је послата на вашу е-адресу. Ако је не примите ускоро, проверите фасцикле за нежељену пошту.<br>Ако није ни тамо, контактирајте вашег администратора.",
     "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Фајлови су вам шифровани. Ако нисте укључили кључ за опоравак, нећете моћи да повратите податке након ресетовања лозинке.<br />Ако нисте сигурни шта да радите, контактирајте администратора пре него што наставите.<br />Да ли желите да наставите?",
     "I know what I'm doing" : "Знам шта радим",
@@ -101,22 +104,20 @@ OC.L10N.register(
     "Strong password" : "Јака лозинка",
     "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Ваш сервер није правилно подешен да омогући синхронизацију фајлова. Изгледа да је ВебДАВ сучеље покварено.",
     "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Овај сервер нема везу са интернетом. То значи да неке могућности, попут монтирања спољашњег складишта, обавештења о ажурирању или инсталација апликација треће стране, неће радити. Даљински приступ и слање е-поште, такође неће радити. Предлажемо да омогућите интернет везу за овај сервер ако желите да имате све могућности.",
-    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Ваш директоријум са подацима и ваши фајлови су вероватно доступни са интернета. Фајл .htaccess не ради. Предлажемо да подесите ваш веб сервер на начин да директоријум са подацима не буде доступан или га изместите изван кореног директоријума веб сервера.",
-    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "Није подешен меморијски кеш. Да бисте побољшали перформансе подесите „memcache“ ако је доступан. Више информација можете наћи у <a href=\"{docLink}\">документацији</a>.",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "/dev/urandom ПХП не може да чита што није добро из безбедносних разлога. Информације о томе можете наћи у нашој <a href=\"{docLink}\">дукументацији</a>.",
     "Error occurred while checking server setup" : "Дошло је до грешке при провери поставки сервера",
+    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Ваш директоријум са подацима и ваши фајлови су вероватно доступни са интернета. Фајл .htaccess не ради. Предлажемо да подесите ваш веб сервер на начин да директоријум са подацима не буде доступан или га изместите изван кореног директоријума веб сервера.",
     "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "ХТТП заглавље „{header}“ није подешено као „{expected}“. Ово потенцијално угрожава безбедност и приватност и препоручујемо да подесите ову поставку.",
     "Shared" : "Дељено",
     "Shared with {recipients}" : "Дељено са {recipients}",
     "Error" : "Грешка",
     "Error while sharing" : "Грешка при дељењу",
     "Error while unsharing" : "Грешка при укидању дељења",
-    "Error while changing permissions" : "Грешка при измени дозвола",
     "Error setting expiration date" : "Грешка при постављању датума истека",
     "The public link will expire no later than {days} days after it is created" : "Јавна веза ће престати да важи {days} дана након стварања",
     "Set expiration date" : "Постави датум истека",
     "Expiration" : "Истиче",
     "Expiration date" : "Датум истека",
+    "Choose a password for the public link" : "Одредите лозинку за јавну везу",
     "Sending ..." : "Шаљем...",
     "Email sent" : "Порука је послата",
     "Resharing is not allowed" : "Поновно дељење није дозвољено",
@@ -124,13 +125,11 @@ OC.L10N.register(
     "Link" : "Веза",
     "Password protect" : "Заштићено лозинком",
     "Password" : "Лозинка",
-    "Choose a password for the public link" : "Одредите лозинку за јавну везу",
     "Allow editing" : "Дозволи уређивање",
     "Email link to person" : "Пошаљи е-поштом",
     "Send" : "Пошаљи",
     "Shared with you and the group {group} by {owner}" : "{owner} дели са вама и са групом {group}.",
     "Shared with you by {owner}" : "{owner} дели са вама",
-    "Shared in {item} with {user}" : "Подељено унутар {item} са корисником {user}",
     "group" : "група",
     "remote" : "удаљени",
     "notify by email" : "обавести е-поштом",
@@ -147,9 +146,10 @@ OC.L10N.register(
     "Share with users or groups …" : "Дели са корисницима или групама...",
     "Share with users, groups or remote users …" : "Дели са корисницима, групама или удаљеним корисницима...",
     "Warning" : "Упозорење",
+    "Delete" : "Обриши",
+    "Rename" : "Преименуј",
     "The object type is not specified." : "Тип објекта није наведен.",
     "Enter new" : "Унесите  нови",
-    "Delete" : "Обриши",
     "Add" : "Додај",
     "Edit tags" : "Уреди ознаке",
     "Error loading dialog template: {error}" : "Грешка при учитавању шаблона дијалога: {error}",
@@ -160,20 +160,11 @@ OC.L10N.register(
     "Hello {name}, the weather is {weather}" : "Здраво {name}, време је {weather}",
     "Hello {name}" : "Здраво {name}",
     "_download %n file_::_download %n files_" : ["преузми %n фајл","преузми %n фајла","преузми %n фајлова"],
-    "{version} is available. Get more information on how to update." : "Верзија {version} је доступна. Сазнајте како да ажурирате.",
     "Updating {productName} to version {version}, this may take a while." : "Надограђујем {productName} на издање {version}. Ово би могло да потраје.",
     "Please reload the page." : "Поново учитајте страницу.",
     "The update was unsuccessful. " : "Ажурирање није успело.",
     "The update was successful. There were warnings." : "Ажурирање је успело. Било је упозорења.",
     "The update was successful. Redirecting you to ownCloud now." : "Ажурирање је успело. Преусмеравам вас на оунКлауд.",
-    "Couldn't reset password because the token is invalid" : "Није могуће ресетовати лозинку јер je токен неважећи",
-    "Couldn't send reset email. Please make sure your username is correct." : "Не могу да пошаљем поруку за ресетовање лозинке. Проверите да ли је корисничко име исправно.",
-    "Couldn't send reset email because there is no email address for this username. Please contact your administrator." : "Не могу да пошаљем поруку за ресетовање лозинке јер за ово корисничко име нема е-адресе. Контактирајте администратора.",
-    "%s password reset" : "%s лозинка ресетована",
-    "Use the following link to reset your password: {link}" : "Употребите следећу везу да ресетујете своју лозинку: {link}",
-    "New password" : "Нова лозинка",
-    "New Password" : "Нова лозинка",
-    "Reset password" : "Ресетуј лозинку",
     "Searching other places" : "Претражујем остала места",
     "Personal" : "Лично",
     "Users" : "Корисници",
@@ -231,6 +222,7 @@ OC.L10N.register(
     "Finishing …" : "Завршавам…",
     "Need help?" : "Треба вам помоћ?",
     "See the documentation" : "Погледајте документацију",
+    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Поздрав,<br><br>само вас обавештавам да %s дели <strong>%s</strong> са вама.<br><a href=\"%s\">Погледајте!</a><br><br>",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Ова апликација захтева Јава скрипт за исправан рад. {linkstart}Омогућите Јава скрипт{linkend} и поново учитајте страницу.",
     "Log out" : "Одјава",
     "Search" : "Претражи",
@@ -239,15 +231,16 @@ OC.L10N.register(
     "An internal error occured." : "Дошло је до интерне грешке.",
     "Please try again or contact your administrator." : "Покушајте поново или контактирајте вашег администратора.",
     "Log in" : "Пријава",
-    "remember" : "упамти",
     "Alternative Logins" : "Алтернативне пријаве",
-    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Поздрав,<br><br>само вас обавештавам да %s дели <strong>%s</strong> са вама.<br><a href=\"%s\">Погледајте!</a><br><br>",
+    "Use the following link to reset your password: {link}" : "Употребите следећу везу да ресетујете своју лозинку: {link}",
+    "New password" : "Нова лозинка",
+    "New Password" : "Нова лозинка",
+    "Reset password" : "Ресетуј лозинку",
     "This ownCloud instance is currently in single user mode." : "Овај оунКлауд тренутно ради у режиму једног корисника.",
     "This means only administrators can use the instance." : "То значи да га могу користити само администратори.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Контактирајте администратора ако се порука понавља или се неочекивано појавила.",
     "Thank you for your patience." : "Хвала вам на стрпљењу.",
     "You are accessing the server from an untrusted domain." : "Приступате серверу са непоузданог домена.",
-    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domain\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Контактирајте администратора. Ако сте ви администратор, подесите „trusted_domain“ поставку у config/config.php фајлу. Пример подешавања имате у config/config.sample.php фајлу.",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Зависно од ваших подешавања, као администратор можете употребити дугме испод да потврдите поузданост домена.",
     "Add \"%s\" as trusted domain" : "Додај „%s“ као поуздан домен",
     "The theme %s has been disabled." : "Тема %s је онемогућена.",
